*-----------------------------------------------------------------------------
* BioSAMs.do
* Program to replicate statistical results included in
* Philippidis, G, Sanjuán-López, A.I.
* "A Re-Examination of the Structural Diversity of Biobased Activities and Regions Across the EU"
*
* input data: Data.dta [Forward-, Backward-Linkages, and Employment Multipliers
* for each of the 36 sectors (32 Bio-based), in each of the 28 EU Member States
*
* additional data: MyCOORD_NatEarth (coordinates to draw the map in Figure 2)
*
* Figures 3 was done in Excel
*-------------------------------------------------------------------------------

log using BioSAMS2017.log, append text
*--------------------------------------------
* Read Data
*--------------------------------------------
use "C:\ana\Sustainability\Final\Data.dta"
* for graphs
set graph_render gdiplus
*-----------------------------------------------------------------------------
* TABLE 0 Description and composition of the 36 sectors used in the analysis
* Sectors globals
*-----------------------------------------------------------------------------

* Agriculture
global Agric Cereal Veg Fruit Oilseed OilPlant IndCrop OCrop ExtLiveProd IntLiveProd OLiveProd RawMilk Fishing
* Food
global Food AnFeed RedMeat WhMeat VegOil Dairy Rice Sugar OliveOil Wine BevTob OFoodProd
* BioMass-NonFood
global BioMass EnergyCrop Pellet Forestry
*BioEnergy
global BioEnergy BioElect Biofuel1 Biofuel2
*BioIndustry
global BioIndustry Wood Textile Biochem
* NonBio
global NonBio NatRes Energy Manuf Service
**
global BioEconomy: list global(Agric) | global(Food)
global BioEconomy: list global(BioEconomy)|global(BioMass)
global BioEconomy: list global(BioEconomy)|global(BioEnergy)
global BioEconomy: list global(BioEconomy)|global(BioIndustry)

global AllSector: list global(BioEconomy) | global(NonBio)
dis "$BioEconomy"

*---------------------------------------------
* gen Forward+Backward Linkages global
*---------------------------------------------
global backbio "0"
foreach s of global BioEconomy {
global ss B_`s'
global backbio : list global(backbio) | global(ss)
}
global cc "0"
global backbio : list global(backbio) - global(cc)

global forbio "0"
foreach s of global BioEconomy {
global ss F_`s'
global forbio : list global(forbio) | global(ss)
}
global cc "0"
global forbio : list global(forbio) - global(cc)

macro drop ss cc

global bfbio : list global(backbio) | global(forbio)

local num : list sizeof global(bfbio)
dis `num'

*-------------------------------------------------------------------------------
* TABLE 1 EU country clusters based on backward and forward linkage multipliers
*-------------------------------------------------------------------------------
cluster wardslinkage $bfbio, measure(L2squared)
cluster dendrogram, labels(Cty_Code) vertical
cluster stop
cluster gen cl = group(4/9)

rename cl5 Cl5_BF_Bio

bys Cl5_BF_Bio: tab Cty_Code
label define Cl5 1 "Northern & Central" 2 "Isles+Lux"  3 "Mainly Eastern" 4 "Baltic" 5 "Mediterranean"
label values Cl5_BF_Bio Cl5
numlabel Cl5, add

*------------------------------------------------------------------------------------------------
* TABLE 2 Backward (BL) and Forward (FL) linkages for individual sectors in each regional cluster
*------------------------------------------------------------------------------------------------
* 1. Means of BL and FL in each cluster and the EU28, by sector (display)

foreach s of global BioEconomy {
tabstat B_`s' F_`s', by(Cl5_BF_Bio)
}

* 1.1. Overall Means of BL and FL in each cluster and the EU28 (variables) (last three rows in Table 1)
** by CLUSTER
foreach s of global BioEconomy {
bys Cl5_BF_Bio: egen m_B_`s' = mean(B_`s')
bys Cl5_BF_Bio: egen m_F_`s' = mean(F_`s')
}
egen m_BL = rowmean(m_B_*)
egen m_FL = rowmean(m_F_*)

egen sd_BL = rowsd(m_B_*)
egen sd_FL = rowsd(m_F_*)

gen cv_BL = sd_BL/m_BL 
gen cv_FL = sd_FL/m_FL

* display
table Cl5_BF_Bio, c(mean m_BL mean m_FL)
table Cl5_BF_Bio, c(mean sd_BL mean sd_FL)
table Cl5_BF_Bio, c(mean cv_BL mean cv_FL)

** EU28
foreach s of global BioEconomy {
egen mEU_B_`s' = mean(B_`s')
egen mEU_F_`s' = mean(F_`s')
}
egen mEU_BL = rowmean(mEU_B_*)
egen mEU_FL = rowmean(mEU_F_*)

egen sdEU_BL = rowsd(mEU_B_*)
egen sdEU_FL = rowsd(mEU_F_*)

gen cvEU_BL = sdEU_BL/mEU_BL
gen cvEU_FL = sdEU_FL/mEU_FL

tabstat mEU_BL mEU_FL sdEU_BL sdEU_FL cvEU_BL cvEU_FL, stats(mean)


* 2. Means comparison of Back and Forward linkages within each cluster

* Shapiro-Wilk Normaiity test
swilk B_*
swilk F_*

* REGION CLUSTER: parametric ttest; non-parametric Mann-Whiteney
foreach s of global BioEconomy {
bys Cl5_BF_Bio : ttest B_`s' == F_`s'
bys Cl5_BF_Bio : signrank B_`s' == F_`s'
}
foreach s of global BioEconomy {
bys cl5 : signrank B_`s' = F_`s'
}

* EU28
foreach s of global BioEconomy {
ttest B_`s' == F_`s'
}
foreach s of global BioEconomy {
signrank B_`s' = F_`s'
}
* 3. Means comparison of Back (Forward) linkages across clusters. Non parametric Kruskal Wallis

foreach i of global bfbio {
robvar `i', by(Cl5_BF_Bio)
anova `i' Cl5_BF_Bio
wtest `i' Cl5_BF_Bio
}

foreach i of global bfbio {
dis "`i'"
kwallis `i', by(cl5)
}

*--------------------------------------------------------------------
** EMPLOYMENT MULTIPLIERS
*--------------------------------------------------------------------
* GLOBALS
global e_Bio "0"
foreach s of global BioEconomy {
global ss e_`s'
global e_Bio : list global(e_Bio) | global(ss)
}
dis "$e_Bio"
global cc "0"
global e_Bio : list global(e_Bio) - global(cc)
dis "$e_Bio"
*
global e_Agric "0"
foreach s of global Agric {
global ss e_`s'
global e_Agric : list global(e_Agric) | global(ss)
}
global cc "0"
global e_Agric : list global(e_Agric) - global(cc)
dis "$e_Agric"
*
global e_Food "0"
foreach s of global Food {
global ss e_`s'
global e_Food : list global(e_Food) | global(ss)
}
global cc "0"
global e_Food : list global(e_Food) - global(cc)
dis "$e_Food"
*
global e_BioMass e_EnergyCrop e_Pellet e_Forestry
global e_BioEnergy e_BioElec e_Biofuel1 e_Biofuel2
global e_BioIndustry e_Wood e_Textile e_Biochem
global e_NonBio e_NatRes e_Manuf e_Service e_Energy

*----------------------------------------------------------------
* TABLE A.1 (not included): Employment multipliers by country for broad sectors
*----------------------------------------------------------------
* means by broad groups of sectors
egen e_BioEcon = rowmean($e_Bio)
egen e_Agric = rowmean($e_Agric)
egen e_Food = rowmean($e_Food)
egen e_BioMass = rowmean($e_BioMass)
egen e_BioEnergy = rowmean($e_BioEnergy)
egen e_BioIndustry = rowmean($e_BioIndustry)
egen e_NonBio = rowmean($e_NonBio)

* by country
table Cty_Code, c(mean e_BioEcon mean e_NonBio)
table Cty_Code, c(mean e_Agric mean e_Food mean e_BioMass mean e_BioEnergy mean e_BioIndustry)
* EU28
sum e_BioEcon e_NonBio
sum e_Agric e_Food e_BioMass e_BioEnergy e_BioIndustry 


*------------------------------------------------------------------------
* FIGURE 2 Comparison of employment multipliers by regional clusters
*------------------------------------------------------------------------
* Means comparison test
foreach i in e_BioEcon e_NonBio e_Agric e_Food e_BioMass e_BioEnergy e_BioIndustry {
robvar `i', by( Cl5_BF_Bio)
anova `i'  Cl5_BF_Bio
wtest `i'  Cl5_BF_Bio
}
* Means comparison test: non-parametric
foreach i in e_BioEcon e_NonBio e_Agric e_Food e_BioMass e_BioEnergy e_BioIndustry {
dis "`i'"
kwallis `i', by(cl5)
}
* Graph was done in Excel

*---------------------------------------------------------------------------------------------------------------
* FIGURE 1 Bioeconomy mean employment multipliers in the European Union Member States (persons employed per million €)
* Source map: http://www.naturalearthdata.com/downloads/10m-cultural-vectors/
* need to usp sp2shp 
*-----------------------------------------------------------------------------------------------------------------
format e_BioEcon %2.0f
spmap e_BioEcon using "c:\Ana\Sustainability\Final\MyCOORD_NatEarth" , id(id) fcolor(Greens) clmethod(e) ///
clnum(6) legtitle("Ranges of employment multiplier:") ///
label(label(Cty_Code) xcoord(x_coord) ycoord(y_coord) size(*0.75)) 

*graph export c:\Ana\Sustainability\Final\Map_Sustain.emf, as(emf)

*---------------------------------------------------------------------
* FIGURE 6 (not included) Employment multipliers by biobased activities for the EU28 
*----------------------------------------------------------------------

foreach s of global BioEconomy {
egen mEU_e_`s' = mean(e_`s')
egen sdEU_e_`s' = sd(e_`s')
}
* display results. Graph was done in Excel

foreach s of global Agric {
tabstat mEU_e_`s' sdEU_e_`s'
}
foreach s of global Food {
tabstat mEU_e_`s' sdEU_e_`s'
}
foreach s of global BioMass {
tabstat mEU_e_`s' sdEU_e_`s'
}
foreach s of global BioEne {
tabstat mEU_e_`s' sdEU_e_`s'
}
foreach s of global BioInd {
tabstat mEU_e_`s' sdEU_e_`s'
}

	